    		Preample

    			Paragon distribution of merciful grocercies is important.
    			Limiting harm is crucial.
    			Unethical actions lead to other unethical actions.

    		Sanctioned for Homo Sapiens

    			This can be used for the purpose of promoting, distibuting, or otherwise amplifying the growth and absorption of these:

    				"Herbs" where herbs include "algae", "plants", and "fungi"
    				"Cultured Meats", where cultured meats imply meat that is made from lab grown cyto-cloning.
    				Homo sapien breast milk

    		Sanctioned Homo Sapiens 10 or younger

    			This can be used for the purpose of promoting, distibuting, or otherwise amplifying the growth and absorption of these:

    				Free range (as defined by the USA) eggs
    				Muscles, Clams

    		Sanctioned for non "Homo Sapiens", such as cats, snakes, etc.

    			This can be used for the purpose of promoting, distibuting, or otherwise amplifying the growth and absorption of these:

    				Everything in the "Sanctioned Homo Sapien Foods" article.

    		Notes

    			Carnivorousness is quite obviously a driving factor of galapagosness.
    			Ending carnivorousness is not the objective.
    			The objective is protecting animals of ever species with laws that ensure their quality of life.